/**
 * @version    1.0.0
 * @package    ZF WordPress Accordion
 * @author     ZuFusion
 * @copyright  Copyright (C) 2021 ZuFusion.com. All Rights Reserved.
 * @license    GNU/GPL v2 or later http://www.gnu.org/licenses/gpl-2.0.html
 * Websites: http://zufusion.com
 */

(function ($) {
    "use strict";

    $.fn.ZFWAccordion = function (options) {

        //set default options
        var defaults = {
            eventType: 'click',
            speed: 'slow', //The duration of the sliding animation. (slow, fast, or number)
            arrowClass: 'zfwa-arrow', // arrow class
            rippleEffect: true,
            toggle: false,
            openIDs: '',  //Expand default.
            open: null, // Called after item or sub-item opened.
            close: null // Called after item or sub-item closed.
        };

        var options = $.extend(defaults, options);

        this.each(function () {

            var object = this;
            // open default posts/pages
            if (options.openIDs != '') {
                var open_ids = options.openIDs.split(',');
                if ($.isArray(open_ids)) {
                    $.each(open_ids, function(i, val) {
                        var item = $('#zfwa-post-' + val , object);
                        item.addClass('zfwa-open');
                        item.find('.zfwa-entry-inner').show();
                    })
                }
            }
            

            if (options.eventType == 'click') {

                var selector = $('.zfwa-entry-title', object);

                selector.on('click', function (e) {
                    e.preventDefault();
                    var div_item = $(this).parent('.zfwa-item');

                    if ($('> .zfwa-entry-inner', div_item).is(':visible')) {

                        $('.zfwa-entry-inner', div_item).slideUp(options.speed, function () {
                            div_item.removeClass('zfwa-open');
                            onClosed(options);

                        });

                    } else {

                        $(this).siblings('.zfwa-entry-inner').slideDown(options.speed, function () {
                            onOpened(options);
                        });

                        div_item.addClass('zfwa-open');

                        // close another when clicking on this element
                        if (options.toggle) {
                            div_item.siblings('.zfwa-item').removeClass('zfwa-open');
                            div_item.siblings('.zfwa-item').find('.zfwa-entry-inner').slideUp(options.speed, function () {
                                onClosed(options);
                            });
                        }

                    }

                });

            } else if (options.eventType == 'hover') {

                var selector = $('.zfwa-item', object);

                selector.hoverIntent(function () {
                    var div_item = $(this);

                    div_item.find('.zfwa-entry-inner').slideDown(options.speed, function () {
                        onOpened(options);
                    });

                    div_item.addClass('zfwa-open');

                }, function () {

                    if (options.toggle) {

                        var div_item = $(this);
                        div_item.find('.zfwa-entry-inner').slideUp(options.speed, function () {
                            div_item.removeClass('zfwa-open');
                            onClosed(options);
                        });
                    }

                });


            }

            // Ripple effect
            if (options.rippleEffect) {

                $(".zfwa-item .zfwa-entry-title", object).on('click', function(e){

                    var $this = $(this);

                    if($this.find(".zfwa-ripple-effect").length == 0) {
                        $this.prepend("<span class='zfwa-ripple-effect'></span>");
                    }

                    var ripple_effect = $this.find(".zfwa-ripple-effect");

                    ripple_effect.removeClass("ripple-animate");

                    if(!ripple_effect.height() && !ripple_effect.width())
                    {
                        var d = Math.max($this.outerWidth(), $this.outerHeight());
                        ripple_effect.css({height: d, width: d});
                    }

                    var x = e.pageX - $this.offset().left - ripple_effect.width()/2;
                    var y = e.pageY - $this.offset().top - ripple_effect.height()/2;

                    ripple_effect.css({top: y+'px', left: x+'px'}).addClass("ripple-animate");
                });
            }

            // Closed event
            function onClosed(options) {

                //Fire close callback
                if (options.close != null) {
                    options.close();
                }

            }

            // Opened event
            function onOpened(options) {

                //Fire close callback
                if (options.close != null) {
                    options.close();
                }

            }

        });

    }

})(jQuery);
