<?php
/**
 * @version    $Id$
 * @package    ZF WordPress Accordion
 * @author     ZuFusion
 * @copyright  Copyright (C) 2021 ZuFusion All Rights Reserved.
 * @license    GNU/GPL v2 or later http://www.gnu.org/licenses/gpl-2.0.html
 */

if (!class_exists('ZF_WordPress_Accordion')) {

    /**
     * Class ZF_WordPress_Accordion base
     */
    class ZF_WordPress_Accordion
    {

        protected static $instance = null;


        private  $footer_extra = '';


        public function run()
        {

            $this->init();
        }

        /**
         * Return an instance of this class.
         */
        public static function get_instance()
        {

            if (null == self::$instance) {
                self::$instance = new self;
            }

            return self::$instance;
        }

        /**
         * Init
         */
        public function init()
        {

            add_action( 'plugins_loaded', array( $this, 'load_textdomain' ) );


            // register widgets
            add_action('widgets_init', array($this, 'register_widgets'));

            add_action('wp_enqueue_scripts', array($this, 'load_assets'));

            add_action( 'wp_footer', array( $this, 'print_footer_extra' ), 30 );

            // include shortcode
            require('shortcode.php');

            if (is_admin()) {
                add_action('admin_enqueue_scripts', array($this, 'admin_assets'));
            }

        }

        /**
         * Load Localisation files.
         */
        public function load_textdomain() {

            $domain = 'zfwa';
            $locale = apply_filters( 'plugin_locale', get_locale(), $domain );

            if ( $loaded = load_textdomain( $domain, trailingslashit( WP_LANG_DIR ) . $domain . '/' . $domain . '-' . $locale . '.mo' ) ) {
                return $loaded;
            } else {
                load_plugin_textdomain( 'zfwa', FALSE, basename(ZF_WORDPRESS_ACCORDION_PLUGIN_PATH) . '/languages/' );
            }

        }

        /**
         * Add extra to the footer.
         * @param $js
         */
        public function add_footer_extra( $js ) {
            $this->footer_extra .= "\n" . $js . "\n";
        }

        /**
         * Print extra to footer
         * @return bool
         */
        public function print_footer_extra( ) {

            if ( $this->footer_extra ) {

                echo $this->footer_extra;

                $this->footer_extra = '';
            }

        }

        /**
         * load assets for plugins
         */
        public function load_assets()
        {

            wp_register_style('zfwa-style', ZF_WORDPRESS_ACCORDION_PLUGIN_URL . 'assets/core/css/style.css', array(), false, 'all');
            wp_enqueue_style('zfwa-style');

            wp_register_script('zfwa-accordion', ZF_WORDPRESS_ACCORDION_PLUGIN_URL . 'assets/core/js/zfwa-accordion.min.js', array('jquery', 'hoverIntent'), '2.4', true);
            wp_enqueue_script('zfwa-accordion');

        }

        /**
         * Enqueue Assets
         */
        public function admin_assets()
        {
            // js
            wp_enqueue_script('jquery');

            add_thickbox();
        }

        /**
         * register widgets function.
         *
         * @access public
         * @return void
         */
        function register_widgets()
        {
            global $zfwa_object;
            $zfwa_object = self::get_instance();

            include_once('widget.php');

            register_widget('ZF_Wordpress_Accordion_Widget');
        }

    }
}