<?php
/**
 * @version    $Id$
 * @package    ZF WordPress Accordion
 * @author     ZuFusion
 * @copyright  Copyright (C) 2021 ZuFusion All Rights Reserved.
 * @license    GNU/GPL v2 or later http://www.gnu.org/licenses/gpl-2.0.html
 */

/**
 * Get all theme styles from assets/css/themes/
 * @return array
 */
function zfwa_get_themes()
{


    // allow custom theme folder
    $dir = ZF_WORDPRESS_ACCORDION_THEMES;

    $themes = zfwa_get_themes_from_path($dir);

    // custom themes
    $addition_dir = zfwa_get_theme_dir();
    if ($addition_dir != $dir) {
        $custom_themes = zfwa_get_themes_from_path($addition_dir);
        if (!empty($custom_themes)) {
            $themes = array_merge($themes, $custom_themes);
        }

    }

    return $themes;
}

function zfwa_get_themes_from_path($dir) {

    $themes = array();

    if (is_dir($dir)) {
        if ($theme_dir = opendir($dir)) {
            while (($theme_file = readdir($theme_dir)) !== false) {
                $ext = pathinfo($theme_file, PATHINFO_EXTENSION);
                if ($ext == 'css') {
                    $key = str_replace('.css', '', $theme_file);
                    $themes[strtolower($key)] = $theme_file;
                }
            }
        }
    }

    return $themes;
}

/**
 * Get theme content
 * @param $theme
 * @return string
 */
function zfwa_get_theme_content($theme) {

    $file_dir = zfwa_get_theme_dir() . '/' . $theme . '.css';
    $content  = '';

    if (file_exists($file_dir)) {
        $content = file_get_contents($file_dir);
    } else {
        // check in default path
        $file_default_path = ZF_WORDPRESS_ACCORDION_THEMES . '/' . $theme . '.css';

        if (file_exists($file_default_path)) {
            $content = file_get_contents($file_default_path);
        }

    }

    return $content;

}

/**
 * get theme dir
 * @return mixed|void
 */
function zfwa_get_theme_dir() {
    return apply_filters('zfwa_theme_dir', ZF_WORDPRESS_ACCORDION_THEMES);
}

/**
 * get template folder of plugin
 * @return mixed|void
 */
function zfwa_template_path() {
    return apply_filters( 'zfwa_template_path', '/zf-wordpress-accordion/templates/' );
}

/**
 * Get a template
 */

function zfwa_get_template( $template, $load = true, $require_once = true ) {

    // Get the template slug
    if ( strpos( $template, '.php' ) == false ) {
        $template = $template . '.php';
    }
    // Check if a custom template exists in the theme folder, if not, load the plugin template file
    $template_path = zfwa_template_path() . $template;

    $cache_key = sanitize_key( implode( '-', array( 'template', $template, $template_path ) ) );
    $file      = (string) wp_cache_get( $cache_key, 'zfwa' );

    if ( ! $file ) {

        if ( $theme_file = locate_template( array( $template_path ) ) ) {
            $file = $theme_file;
        } else {
            $file = ZF_WORDPRESS_ACCORDION_PLUGIN_PATH . 'templates/' . $template;
        }

        wp_cache_set( $cache_key, $file, 'zfwa' );
    }

    $file_filter = apply_filters( 'zfwa_get_template', $file, $template );

    if ( $file_filter !== $file ) {
        $file = $file_filter;
    }
    if ( $load && '' != $file ) {
        load_template( $file, $require_once );
    }

    return $file;
}