<?php
/**
 * @version    $Id$
 * @package    ZF WordPress Accordion
 * @author     ZuFusion
 * @copyright  Copyright (C) 2021 ZuFusion All Rights Reserved.
 * @license    GNU/GPL v2 or later http://www.gnu.org/licenses/gpl-2.0.html
 */
function zfwa_accordion_shortcode( $atts, $content = null )
{
    global $zfwa;

    extract( shortcode_atts( array(

        'number' => 10,
        'post_type' => 'post',
        'theme' => 'classic',
        'title' => '',
        'speed' => 'slow',
        'event_type' => 'click',
        'arrow_alignment' => 'right',
        'orderby' => 'date',
        'order' => 'desc',
        'exclude' => '',
        'include' => '',
        'open_default' => '',
        'ripple_effect' => 'true',
        'toggle' => 'true',
        'show_image' => 'true',

    ), $atts ) );

    $shortcode_id = 'zfwa_shortcode_' . rand(1, 10000);


    $speed = (is_numeric($speed)) ? (int)$speed : '"' . $speed . '"';

    $include = preg_replace( '/[^0-9,]/', '', $include);
    $include_array = ( $include ) ? explode( ',', $include ) : array();

    $exclude = preg_replace( '/[^0-9,]/', '', $exclude);
    $exclude_array = ( $exclude ) ? explode( ',', $exclude ) : array();


    $configs = array(
        'posts_per_page'     => $number,
        'orderby'    => $orderby,
        'order'      => $order,
        'post_type'  => $post_type,
        'post_status'    => 'publish',
    );

    if (!empty($include_array)) {
        $configs['post__in'] = $include_array;
    }
    if (!empty($exclude_array)) {
        $configs['post__not_in'] = $exclude_array;
    }

    $title = empty($title) ? '' : apply_filters('zfwa_title', $title);

    $open_ids = preg_replace( '/[^0-9,]/', '', $open_default);

    $html = '';

    $content  = zfwa_get_theme_content($theme);

    if (!empty($content)) {
        $html = '<style id="style-' . esc_attr($shortcode_id) . '">';
        $html .= str_replace('.zfwa-accordion', '#zfwa-accordion-' . esc_attr( $shortcode_id), $content);
        $html .= '</style>';
    }


    if (!empty($title)) {
        $html .=  '<h3>'.esc_attr($title).'</h3>';
    }

    $template_loop_item = 'loop-item';
    $loop = zfwa_get_template($template_loop_item . '-' . $post_type, false, false);
    if (!file_exists($loop)) {
        $loop = zfwa_get_template($template_loop_item , false, false);
    }
    ob_start();
    ?>
    <div id="zfwa-accordion-<?php echo esc_attr($shortcode_id); ?>" class="zfwa-accordion">
        <div class="<?php echo 'zfwa-' . esc_attr($arrow_alignment);?>">
            <?php
            query_posts($configs);

            if ($loop != '') {
                include $loop;
            }

            wp_reset_query();
            ?>
        </div>
    </div>

    <?php
    $html .= ob_get_clean();
    ob_start();
    ?>
    <script type="text/javascript">
        /* <![CDATA[ */
        (function ($) {
            "use strict";

            $('#zfwa-accordion-<?php echo esc_attr($shortcode_id);?>').ZFWAccordion({
                eventType: '<?php echo esc_attr($event_type);?>',
                speed: <?php echo $speed;?>,
                rippleEffect: <?php echo esc_attr($ripple_effect) ;?>,
                toggle: <?php echo esc_attr($toggle);?>,
                openIDs: '<?php echo esc_attr($open_ids);?>',
            });

        })(jQuery);

        /* ]]> */
    </script>

    <?php

    $js = ob_get_clean();
    $zfwa->add_footer_extra($js);


    return $html;
}

add_shortcode('zfwa', 'zfwa_accordion_shortcode');


/**
 * Create a shortcode button for tinymce
 *
 * @return [type] [description]
 */
function zfwa_button()
{
    if (current_user_can('edit_posts') && current_user_can('edit_pages')) {
        add_filter('mce_external_plugins', 'zfwa_add_buttons');
        add_filter('mce_buttons', 'zfwa_register_buttons');
    }
}

/**
 * Add new button to tinymce
 *
 * @param  Array $buttons - Array of buttons
 *
 * @return Array
 */
function zfwa_register_buttons($buttons)
{
    array_push($buttons, '|', 'zfwa_wp_category_accordion');

    return $buttons;
}

/**
 * Add new Javascript to the plugin scrippt array
 *
 * @param  Array $plugin_array - Array of scripts
 *
 * @return Array
 */
function zfwa_add_buttons($plugin_array)
{
    if ( version_compare( get_bloginfo('version'), '3.9', '>=' ) ) {
        $plugin_array['zfwa_wp_category_accordion'] = ZF_WORDPRESS_ACCORDION_PLUGIN_URL . 'inc/tinymce/js/button9.js';
    } else {
        $plugin_array['zfwa_wp_category_accordion'] = ZF_WORDPRESS_ACCORDION_PLUGIN_URL . 'inc/tinymce/js/button.js';
    }


    return $plugin_array;
}

add_action('admin_init', 'zfwa_button');