<?php

/**
 * @version    $Id$
 * @package    ZF WordPress Accordion
 * @author     ZuFusion
 * @copyright  Copyright (C) 2021 ZuFusion All Rights Reserved.
 * @license    GNU/GPL v2 or later http://www.gnu.org/licenses/gpl-2.0.html
 */
class ZF_Wordpress_Accordion_Widget extends WP_Widget
{
    var $style = '';

    function __construct()
    {
        $this->my_fake_id = uniqid();
        
        $widget_ops = array(
            'description' => esc_html__('Display posts/pages as accordion', 'zfwa'),
            'name'        => esc_html__('ZF WordPress Accordion', 'zfwa')
        );
        parent::__construct('zfwa_widget', esc_html__('ZF WordPress Accordion', 'zfwa'), $widget_ops);
    }

    public function form($instance)
    {
        $instance = wp_parse_args($instance,
            array(
                'speed'           => 'slow',
                'title'           => '',
                'include'           => '',
                'exclude'         => '',
                'open_default'    => '',
                'event_type'      => 'click',
                'arrow_alignment' => 'right',
                'orderby'         => 'date',
                'order'           => 'desc',
                'number'          => 10,
                'post_type'        => 'post',
                'theme'           => 'classic',
            )
        );

        $title              = esc_attr($instance['title']);
        $toggle     = isset($instance['toggle']) ? (bool)$instance['toggle'] : false;
        $ripple_effect = isset($instance['ripple_effect']) ? (bool)$instance['ripple_effect'] : true;
        $show_image = isset($instance['show_image']) ? (bool)$instance['show_image'] : true;
        $exclude            = esc_attr($instance['exclude']);
        $include            = esc_attr($instance['include']);
        $open_default       = esc_attr($instance['open_default']);
        $number             = $instance['number'];
        $themes             = zfwa_get_themes();

        ?>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id('title') ); ?>"><?php esc_attr_e('Title', 'zfwa');?> : </label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id('title') ); ?>"
                   name="<?php echo esc_attr( $this->get_field_name('title') ); ?>" type="text"
                   value="<?php echo esc_attr($title); ?>"/>
        </p>


        <p>
            <label for="<?php echo esc_attr( $this->get_field_id('speed') ); ?>"><?php esc_attr_e('Speed', 'zfwa');?>:</label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id('speed') ); ?>"
                   name="<?php echo esc_attr( $this->get_field_name('speed') ); ?>" type="text"
                   value="<?php echo esc_attr($instance['speed']); ?>"/>
            <br/>
            <small><?php esc_attr_e('The duration of the sliding animation. (slow, fast, or milliseconds).'); ?></small>
        </p>

        <p>
            <label for="<?php echo esc_attr( $this->get_field_id('event_type') ); ?>"><?php esc_attr_e('Event Type', 'zfwa');?>:</label>
            <select name="<?php echo esc_attr( $this->get_field_name('event_type') ); ?>"
                    id="<?php echo esc_attr( $this->get_field_id('event_type') ); ?>" class="widefat">
                <option value="click"<?php selected($instance['event_type'], 'click'); ?>><?php esc_attr_e('Click', 'zfwa'); ?></option>
                <option value="hover"<?php selected($instance['event_type'], 'hover'); ?>><?php esc_attr_e('Hover', 'zfwa'); ?></option>
            </select>
        </p>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id('arrow_alignment') ); ?>"><?php esc_attr_e('Arrow alignment', 'zfwa');?>:</label>
            <select name="<?php echo esc_attr( $this->get_field_name('arrow_alignment') ); ?>"
                    id="<?php echo esc_attr( $this->get_field_id('arrow_alignment') ); ?>" class="widefat">
                <option value="left"<?php selected($instance['arrow_alignment'], 'left'); ?>><?php esc_attr_e('Left', 'zfwa'); ?></option>
                <option value="right"<?php selected($instance['arrow_alignment'], 'right'); ?>><?php esc_attr_e('Right', 'zfwa'); ?></option>
            </select>
        </p>

        <p>
            <label for="<?php echo esc_attr( $this->get_field_id('theme') ); ?>"><?php esc_attr_e('Color Scheme', 'zfwa'); ?>:</label>
            <select name="<?php echo esc_attr( $this->get_field_name('theme') ); ?>"
                    id="<?php echo esc_attr( $this->get_field_id('theme') ); ?>" class="widefat">
                <?php
                if (!empty($themes)) {

                    foreach ($themes as $key => $theme) {
                        ?>
                        <option
                            value="<?php echo esc_attr($key); ?>"<?php selected($instance['theme'], $key); ?>><?php echo esc_attr($key) ; ?></option>
                    <?php
                    }
                } else { ?>
                    <option disabled><?php esc_attr_e('Not found', 'zfwa');?></option>
                <?php }
                ?>
            </select>
        </p>
        <p>
            <?php

                $post_types = get_post_types( array('public' => true, '_builtin' => true ), 'objects', 'or' );
                unset($post_types['revision']);
                unset($post_types['attachment']);
                unset($post_types['nav_menu_item']);
                $post_type_arr = array();
                foreach ( $post_types  as $post_type ) {
                    $post_type_arr[$post_type->name] = $post_type->label;
                }

            ?>
            <label for="<?php echo esc_attr( $this->get_field_id('post_type') ); ?>"><?php esc_attr_e('Post type', 'zfwa'); ?>:</label>
            <select name="<?php echo esc_attr( $this->get_field_name('post_type') ); ?>"
                    id="<?php echo esc_attr( $this->get_field_id('post_type') ); ?>" class="widefat">
	            <?php
	            foreach ( $post_type_arr as $post_type_value => $post_type_label ) {
		            ?>
                    <option value="<?php echo esc_attr($post_type_value);?>"<?php selected($instance['post_type'], $post_type_value); ?>><?php echo esc_html($post_type_label); ?></option>
		            <?php
	            }
	            ?>
            </select>
        </p>

        <p>
            <label for="<?php echo esc_attr( $this->get_field_id('orderby') ); ?>"><?php esc_attr_e('Order by', 'zfwa'); ?>:</label>
            <select name="<?php echo esc_attr( $this->get_field_name('orderby') ); ?>"
                    id="<?php echo esc_attr( $this->get_field_id('orderby') ); ?>" class="widefat">
                <option value="date"<?php selected($instance['orderby'], 'id'); ?>><?php esc_attr_e('Date', 'zfwa'); ?></option>
                <option value="rand"<?php selected($instance['orderby'], 'name'); ?>><?php esc_attr_e('Random', 'zfwa'); ?></option>
                <option value="title"<?php selected($instance['orderby'], 'count'); ?>><?php esc_attr_e('Title', 'zfwa'); ?></option>
            </select>
        </p>

        <p>
            <label for="<?php echo esc_attr( $this->get_field_id('order') ); ?>"><?php esc_attr_e('Order:'); ?></label>
            <select name="<?php echo esc_attr( $this->get_field_name('order') ); ?>"
                    id="<?php echo esc_attr( $this->get_field_id('order') ); ?>" class="widefat">
                <option value="asc"<?php selected($instance['order'], 'asc'); ?>><?php esc_attr_e('Asc', 'zfwa'); ?></option>
                <option value="desc"<?php selected($instance['order'], 'desc'); ?>><?php esc_attr_e('Desc', 'zfwa'); ?></option>
            </select>
        </p>

        <p>
            <label for="<?php echo esc_attr( $this->get_field_id('include') ); ?>"><?php esc_attr_e('Include', 'zfwa'); ?>:</label>
            <input type="text" value="<?php echo esc_attr($include); ?>" name="<?php echo esc_attr( $this->get_field_name('include') ); ?>"
                id="<?php echo esc_attr( $this->get_field_id('include') ); ?>" class="widefat"/>
            <br/>
            <small><?php esc_attr_e('Post/page IDs, separated by commas.'); ?></small>
        </p>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id('exclude') ); ?>"><?php esc_attr_e('Exclude', 'zfwa'); ?>:</label>
            <input type="text" value="<?php echo esc_attr($exclude); ?>" name="<?php echo esc_attr( $this->get_field_name('exclude') ); ?>"
                id="<?php echo esc_attr( $this->get_field_id('exclude') ); ?>" class="widefat"/>
            <br/>
            <small><?php esc_attr_e('Post/page IDs, separated by commas.'); ?></small>
        </p>

        <p>
            <label for="<?php echo esc_attr( $this->get_field_id('open_default') ); ?>"><?php esc_attr_e('Open default', 'zfwa'); ?>:</label>
            <input type="text" value="<?php echo esc_attr($open_default); ?>" name="<?php echo esc_attr( $this->get_field_name('open_default') ); ?>"
                id="<?php echo esc_attr( $this->get_field_id('open_default') ); ?>" class="widefat"/>
            <br/>
            <small><?php esc_attr_e('Expand default post/page IDs, separated by commas.'); ?></small>
        </p>
        <p>
            <label
                for="<?php echo esc_attr(  $this->get_field_id('number') ); ?>"><?php esc_attr_e('Limit number of items', 'zfwa'); ?>:</label>
            <input type="text" value="<?php echo esc_attr( $number ); ?>" name="<?php echo esc_attr( $this->get_field_name('number') ); ?>"
                   id="<?php echo esc_attr( $this->get_field_id('number') ); ?>" class="widefat"/>
        </p>

        <p>
            <input type="checkbox" class="checkbox" <?php checked($ripple_effect); ?>
                   id="<?php echo  esc_attr( $this->get_field_id('ripple_effect') ); ?>"
                   name="<?php echo  esc_attr( $this->get_field_name('ripple_effect') ); ?>"/>
            <label
                for="<?php echo  esc_attr( $this->get_field_id('ripple_effect') ); ?>"><?php esc_attr_e('Ripple Effect', 'zfwa'); ?> ?</label>
        </p>
        <p>
            <input type="checkbox" class="checkbox" <?php checked($toggle); ?>
                   id="<?php echo  esc_attr( $this->get_field_id('toggle') ); ?>"
                   name="<?php echo esc_attr( $this->get_field_name('toggle') ); ?>"/>
            <label
                for="<?php echo esc_attr( $this->get_field_id('toggle') ); ?>"><?php esc_attr_e('Toggle Accordion', 'zfwa'); ?> ?</label>
        </p>
        <p>
            <input type="checkbox" class="checkbox" <?php checked($show_image); ?>
                   id="<?php echo  esc_attr( $this->get_field_id('show_image') ); ?>"
                   name="<?php echo esc_attr( $this->get_field_name('show_image') ); ?>"/>
            <label
                for="<?php echo esc_attr( $this->get_field_id('show_image') ); ?>"><?php esc_attr_e('Show image', 'zfwa'); ?> ?</label>
        </p>

    <?php

    }

    function update($new_instance, $old_instance)
    {

        $instance                       = $old_instance;
        $instance['title']              = strip_tags($new_instance['title']);
        $instance['speed']              = strip_tags($new_instance['speed']);
        $instance['event_type']         = $new_instance['event_type'];
        $instance['arrow_alignment']    = $new_instance['arrow_alignment'];
        $instance['theme']              = $new_instance['theme'];
        $instance['number']             = $new_instance['number'];
        $instance['toggle']     = !empty($new_instance['toggle']) ? 1 : 0;
        $instance['ripple_effect'] = !empty($new_instance['ripple_effect']) ? 1 : 0;
        $instance['show_image'] = !empty($new_instance['show_image']) ? 1 : 0;

        $instance['orderby'] = $new_instance['orderby'];
        $instance['order'] = $new_instance['order'];
        $instance['post_type'] = $new_instance['post_type'];
        $instance['include'] = $new_instance['include'];
        $instance['exclude'] = $new_instance['exclude'];
        $instance['open_default'] = $new_instance['open_default'];

        return $instance;
    }

    public function widget($args, $instance)
    {
        global $zfwa;

        extract($args, EXTR_SKIP);
        $speed = $instance['speed'];

        $speed = (is_numeric($speed)) ? (int)$speed : '"' . $speed . '"';
        $show_image = !empty($instance['show_image']) ? 'true' : 'false';
        $ripple_effect = !empty($instance['ripple_effect']) ? 'true' : 'false';
        $toggle      = !empty($instance['toggle']) ? 'true' : 'false';

        $orderby          = empty($instance['orderby']) ? 'name' : $instance['orderby'];
        $order            = empty($instance['order']) ? 'asc' : $instance['order'];
        $include          = empty($instance['include']) ? '' : $instance['include'];
        $exclude          = empty($instance['exclude']) ? '' : $instance['exclude'];
        $limit_posts = empty($instance['number']) ? 10 : $instance['number'];
        $post_type         = empty($instance['post_type']) ? 'post' : $instance['post_type'];
        $theme            = empty($instance['theme']) ? 'classic' : $instance['theme'];
        $event_type       = empty($instance['event_type']) ? 'click' : $instance['event_type'];
        $arrow_alignment  = empty($instance['arrow_alignment']) ? 'right' : $instance['arrow_alignment'];
        $open_default     = empty($instance['open_default']) ? '' : $instance['open_default'];

        $open_ids = preg_replace( '/[^0-9,]/', '', $open_default);


        $content  = zfwa_get_theme_content($theme);

        if (!empty($content)) {

            $style = '<style id="style-zfwa-accordion-' . esc_attr( $this->my_fake_id ) . '">';
            $style .= str_replace('.zfwa-accordion', '#zfwa-accordion-' . esc_attr( $this->my_fake_id ), $content);
            $style .= '</style>';

            echo $style;
        }

        $include = preg_replace( '/[^0-9,]/', '', $include);
        $include_array = ( $include ) ? explode( ',', $include ) : array();

        $exclude = preg_replace( '/[^0-9,]/', '', $exclude);
        $exclude_array = ( $exclude ) ? explode( ',', $exclude ) : array();

        $configs = array(
            'posts_per_page'     => $limit_posts,
            'orderby'    => $orderby,
            'order'      => $order,
            'post_type'  => $post_type,
            'post_status'    => 'publish',
        );

        if (!empty($include_array)) {
            $configs['post__in'] = $include_array;
        }
        if (!empty($exclude_array)) {
            $configs['post__not_in'] = $exclude_array;
        }

        echo $before_widget;

        $title = empty($instance['title']) ? '' : apply_filters('widget_title', $instance['title']);

        if (!empty($title)) {
            echo $before_title . esc_attr($title) . $after_title;
        }

        $template_loop_item = 'loop-item';
        $loop = zfwa_get_template($template_loop_item . '-' . $post_type, false, false);
        if (!file_exists($loop)) {
            $loop = zfwa_get_template($template_loop_item , false, false);
        }
        ?>
        <div id="zfwa-accordion-<?php echo esc_attr($this->my_fake_id); ?>" class="zfwa-accordion">
            <div class="<?php echo 'zfwa-' . esc_attr($arrow_alignment);?>">
                <?php
                query_posts($configs);
                ob_start();
                if ($loop != '') {
                    include $loop;
                }
                echo ob_get_clean();
                wp_reset_query();
                ?>
            </div>
        </div>
        <?php
        ob_start();
        ?>
        <script type="text/javascript">
            /* <![CDATA[ */
            (function ($) {
                "use strict";
                $('#zfwa-accordion-<?php echo esc_attr($this->my_fake_id);?>').ZFWAccordion({
                    eventType: '<?php echo esc_attr($event_type);?>',
                    speed: <?php echo $speed;?>,
                    rippleEffect: <?php echo esc_attr($ripple_effect) ;?>,
                    toggle: <?php echo esc_attr($toggle);?>,
                    openIDs: '<?php echo esc_attr($open_ids);?>',
                });

            })(jQuery);

            /* ]]> */
        </script>

        <?php
        $js = ob_get_clean();
        $zfwa->add_footer_extra($js);
        echo $after_widget;
    }


}